@@ -1,5 +1,5 @@
 package Data::Verifier;
-$Data::Verifier::VERSION = '0.57';
+$Data::Verifier::VERSION = '0.58';
 use Moose;
 
 # ABSTRACT: Profile based data verification with Moose type constraints.
@@ -207,7 +207,7 @@ sub verify {
             elsif(my $coercion = $fprof->{coercion}) {
                 $val = $coercion->coerce($val);
             }
-    
+
             unless($cons->check($val)) {
                 $field->reason('type_constraint');
                 $field->valid(0);
@@ -290,13 +290,13 @@ sub verify {
             my $rv = $results->$der();
 
             my $req = $prof->{required};
-            
+
             my $field = Data::Verifier::Field->new;
             # If the field is required and we got back undef then this
             # is a bad value!
             if(defined($req) && $req && !defined($rv)) {
                 $field->valid(0);
-                
+
                 my $dfields = $prof->{fields};
                 foreach my $df (@{ $dfields }) {
                     my $f = $results->get_field($df);
@@ -363,46 +363,7 @@ Data::Verifier - Profile based data verification with Moose type constraints.
 
 =head1 VERSION
 
-version 0.57
-
-=head1 SYNOPSIS
-
-    use Data::Verifier;
-
-    my $dv = Data::Verifier->new(
-        filters => [ qw(trim) ],
-        profile => {
-            name => {
-                required    => 1,
-                type        => 'Str',
-               filters     => [ qw(collapse) ]
-            },
-            age  => {
-                type        => 'Int'
-            },
-            sign => {
-                required    => 1,
-                type        => 'Str'
-            }
-        }
-    );
-
-    # Pass in a hash of data
-    my $results = $dv->verify({
-        name => 'Cory', age => 'foobar'
-    });
-
-    $results->success; # no
-
-    $results->is_invalid('name'); # no
-    $results->is_invalid('age');  # yes
-
-    $results->is_missing('name'); # no
-    $results->is_missing('sign'); # yes
-
-    $results->get_original_value('name'); # Unchanged, original value
-    $results->get_value('name'); # Filtered, valid value
-    $results->get_value('age');  # undefined, as it's invalid
+version 0.58
 
 =head1 DESCRIPTION
 
@@ -544,6 +505,46 @@ Finally any derived fields are run.
 
 =back
 
+=encoding utf8
+=head1 SYNOPSIS
+
+    use Data::Verifier;
+
+    my $dv = Data::Verifier->new(
+        filters => [ qw(trim) ],
+        profile => {
+            name => {
+                required    => 1,
+                type        => 'Str',
+               filters     => [ qw(collapse) ]
+            },
+            age  => {
+                type        => 'Int'
+            },
+            sign => {
+                required    => 1,
+                type        => 'Str'
+            }
+        }
+    );
+
+    # Pass in a hash of data
+    my $results = $dv->verify({
+        name => 'Cory', age => 'foobar'
+    });
+
+    $results->success; # no
+
+    $results->is_invalid('name'); # no
+    $results->is_invalid('age');  # yes
+
+    $results->is_missing('name'); # no
+    $results->is_missing('sign'); # yes
+
+    $results->get_original_value('name'); # Unchanged, original value
+    $results->get_value('name'); # Filtered, valid value
+    $results->get_value('age');  # undefined, as it's invalid
+
 =head1 ATTRIBUTES
 
 =head2 derived
@@ -599,7 +600,7 @@ An example:
     );
 
 In the above example a field named C<full_name> will be created that is
-the other two fields concatenated.  If the derived field is required and 
+the other two fields concatenated.  If the derived field is required and
 C<deriver> subref returns undef then the derived field B<and> the fields
 listed in C<fields> will also be invalid.
 
@@ -623,7 +624,7 @@ type system.  If this is set, coercion will be ignored.
 
 =item B<coercion>
 
-Set this attribute to the coercion defined for this type.  If B<coerce> is 
+Set this attribute to the coercion defined for this type.  If B<coerce> is
 set this attribute will be ignored.  See the C<coercion> method above.
 
 =item B<dependent>
@@ -650,7 +651,7 @@ and password2 is missing then password will be invalid.
 
 =item B<filters>
 
-An optional list of filters through which this specific value will be run. 
+An optional list of filters through which this specific value will be run.
 See the documentation for L<Data::Verifier::Filters> to learn more.  This
 value my be either a scalar (string or coderef) or an arrayref of strings or
 coderefs.
@@ -736,7 +737,7 @@ result.
 =head2 coercion
 
 Define a coercion to use for verification.  This will not define a global
-Moose type coercion, but is instead just a single coercion to apply to a 
+Moose type coercion, but is instead just a single coercion to apply to a
 specific entity.
 
     my $verifier = Data::Verifier->new(
@@ -744,7 +745,7 @@ specific entity.
             a_string => {
                 type     => 'Str',
                 coercion => Data::Verifier::coercion(
-                    from => 'Int', 
+                    from => 'Int',
                         via => sub { (qw[ one two three ])[ ($_ - 1) ] }
                 ),
             },
@@ -774,6 +775,8 @@ J. Shirley
 
 Wallace Reis
 
+Mohammad S Anwar
+
 =head1 AUTHOR
 
 Cory G Watson <gphat@cpan.org>
